@@ -1,4 +1,4 @@
-__all__ = ('UserProfilePoint', 'RussianProfilePoint', 'RussianProfileObjectPoint')
+__all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint')
 
 from expressmoney.api import *
 
@@ -12,6 +12,11 @@ class UserProfileCreateContract(Contract):
     http_referer = serializers.URLField()
 
 
+class UserProfileReadContract(UserProfileCreateContract):
+    created = serializers.DateTimeField()
+    country = serializers.CharField(max_length=2)
+
+
 class ProfileUpdateContract(Contract):
     first_name = serializers.CharField(max_length=32)
     last_name = serializers.CharField(max_length=32)
@@ -109,6 +114,11 @@ class UserProfilePoint(CreatePointMixin, ContractPoint):
     _create_contract = UserProfileCreateContract
 
 
+class UserProfileObjectPoint(RetrievePointMixin, ContractObjectPoint):
+    _point_id = UserProfileID()
+    _read_contract = UserProfileReadContract
+
+
 class RussianProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = RussianProfileID()
     _create_contract = RussianProfileCreateContract
